@@ -271,7 +271,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
             not (is_devel_pkg(self.package_base) and check_dev_pkgs)
         ):
             return
-        print_stdout('{} {}...'.format(
+        print_stdout('{} {}...'.format(  # pylint: disable=consider-using-f-string
             color_line('::', 15),
             _n(
                 "Downloading the latest sources for a devel package {}",
@@ -386,7 +386,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
         if not self.built_deps_to_install:
             return
 
-        print_stderr('{} {}:'.format(
+        print_stderr('{} {}:'.format(  # pylint: disable=consider-using-f-string
             color_line('::', 13),
             _("Installing already built dependencies for {}").format(
                 bold_line(', '.join(self.package_names)))
@@ -395,7 +395,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
         try:
             update_self_deps = False
             for pkg_name, pkg_build in all_package_builds.items():
-                if pkg_name in self.built_deps_to_install.keys():
+                if pkg_name in self.built_deps_to_install:
                     pkg_build.install_built_deps(all_package_builds)
                     update_self_deps = True
             if update_self_deps:
@@ -452,7 +452,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
                 not self.args.rebuild and
                 len(self.built_packages_paths) == len(self.package_names)
         ):
-            print_stderr("{} {}\n".format(
+            print_stderr("{} {}\n".format(  # pylint: disable=consider-using-f-string
                 color_line("::", 10),
                 _n(
                     "Package {pkg} is already built. Pass '--rebuild' flag to force the build.",
@@ -529,7 +529,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
         if not self.all_deps_to_install:
             return
 
-        print_stderr('{} {}:'.format(
+        print_stderr('{} {}:'.format(  # pylint: disable=consider-using-f-string
             color_line('::', 13),
             _("Installing repository dependencies for {}").format(
                 bold_line(', '.join(self.package_names)))
@@ -599,7 +599,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
         if not deps_packages_installed or self.args.keepbuilddeps:
             return
 
-        print_stderr('{} {}:'.format(
+        print_stderr('{} {}:'.format(  # pylint: disable=consider-using-f-string
             color_line('::', 13),
             _("Removing already installed dependencies for {}").format(
                 bold_line(', '.join(self.package_names)))
@@ -647,13 +647,14 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
         if not color_enabled():
             makepkg_args.append('--nocolor')
 
-        print_stderr('\n{} {}:'.format(
+        print_stderr('\n{} {}:'.format(  # pylint: disable=consider-using-f-string
             color_line('::', 13),
             _('Starting the build')
         ))
         build_succeeded = False
         skip_pgp_check = False
         skip_file_checksums = False
+        skip_check = False
         while True:
             cmd_args = MakePkgCommand.get() + makepkg_args
             if skip_pgp_check:
@@ -662,6 +663,8 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
                 cmd_args += ['--skipchecksums']
             if self.skip_carch_check:
                 cmd_args += ['--ignorearch']
+            if skip_check:
+                cmd_args += ['--nocheck']
             cmd_args = isolate_root_cmd(cmd_args, cwd=self.build_dir)
             spawn_kwargs: Dict[str, Any] = {}
             if self.args.hide_build_log:
@@ -687,13 +690,14 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
             elif self.args.noconfirm:
                 answer = _("a")
             else:  # pragma: no cover
-                prompt = '{} {}\n{}\n> '.format(
+                prompt = '{} {}\n{}\n> '.format(  # pylint: disable=consider-using-f-string
                     color_line('::', 11),
                     _("Try recovering?"),
                     "\n".join((
                         _("[R] retry build"),
                         _("[p] PGP check skip"),
                         _("[c] checksums skip"),
+                        _("[f] check() skip"),
                         _("[i] ignore architecture"),
                         _("[d] delete build dir and try again"),
                         _("[e] edit PKGBUILD"),
@@ -704,7 +708,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
                 )
                 answer = get_input(
                     prompt,
-                    _('r').upper() + _('p') + _('c') + _('i') + _('d') + _('e') +
+                    _('r').upper() + _('p') + _('c') + _('f') + _('i') + _('d') + _('e') +
                     _('s') + _('a')
                 )
 
@@ -717,6 +721,9 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
             if answer == _("c"):  # pragma: no cover
                 skip_file_checksums = True
                 continue
+            if answer == _("f"):  # pragma: no cover
+                skip_check = True
+                continue
             if answer == _("i"):  # pragma: no cover
                 self.skip_carch_check = True
                 continue
